pub type CF2<C> = <<C as CurveGroup>::BaseField as Field>::BasePrimeField;Expand description
CF2 is a type alias for the base field of a curve C.
pub type CF2<C> = <<C as CurveGroup>::BaseField as Field>::BasePrimeField;CF2 is a type alias for the base field of a curve C.