SparseMatrixVar

Struct SparseMatrixVar 

pub struct SparseMatrixVar<FV>(pub Vec<Vec<(FV, usize)>>);
SparseMatrixVar is a sparse matrix represented as a vector of rows, where each row is a vector of (value, column_index) pairs.

This follows the same format as ark_relations::gr1cs::Matrix.

Tuple Fields

0: Vec<Vec<(FV, usize)>>