R1CSMatricesVar

Struct R1CSMatricesVar 

pub struct R1CSMatricesVar<FVar> { /* private fields */ }
R1CSMatricesVar is the in-circuit variable of a given R1CS structure.

Only the matrices are represented, while the remaining R1CS parameters are constants to the circuit.

The naming is chosen to distinguish from arkworks’ (G)R1CSVar.

Implementations

Source

impl<FVar> R1CSMatricesVar<FVar>
where SparseMatrixVar<FVar>: MatrixGadget<FVar>, [FVar]: VectorGadget<FVar>, for<'a> &'a FVar: Mul<&'a FVar, Output = FVar>,

pub fn evaluate_r1cs( &self, z: Assignments<FVar, impl AsRef<[FVar]>>, ) -> Result<Vec<FVar>, SynthesisError>

R1CSMatricesVar::evaluate_r1cs is the in-circuit version of R1CS::evaluate_r1cs that evaluates the R1CS variable at a given vector of assignments z.