R1CS

Struct R1CS 

pub struct R1CS<F: Field> { /* private fields */ }
R1CS holds the three sparse matrices A, B, C together with the configuration.

Implementations

Source

impl<F: Field> R1CS<F>

pub fn new( n_constraints: usize, n_variables: usize, n_public_inputs: usize, matrices: [Matrix<F>; 3], ) -> Result<Self, Error>

R1CS::new creates a new R1CS structure from the given configuration and matrices.

pub fn validate(&self) -> Result<(), Error>

R1CS::validate checks that the structural invariant of the R1CS holds, i.w., every matrix has exactly m rows (one per constraint), and no column index reaches beyond the n variables.

pub fn new_without_validity_check( n_constraints: usize, n_variables: usize, n_public_inputs: usize, matrices: [Matrix<F>; 3], ) -> Self

R1CS::new_without_validity_check creates a new R1CS structure from the given configuration and matrices without checking their validity.

pub fn evaluate_r1cs( &self, z: Assignments<F, impl AsRef<[F]> + Sync>, ) -> Result<Vec<F>, Error>

R1CS::evaluate_r1cs evaluates the R1CS relation at a given vector of assignments z.

This method is simply a wrapper of CCS::evaluate_ccs with fixed coefficients and multisets.