ArithConfig

Struct ArithConfig 

pub struct ArithConfig {
    pub degree: usize,
    pub n_constraints: usize,
    pub n_variables: usize,
    pub n_public_inputs: usize,
    pub n_witnesses: usize,
}
ArithConfig describes the configuration of a constraint system.

Fields

degree: usize

ArithConfig::degree specifies the degree of the constraint system.

n_constraints: usize

ArithConfig::n_constraints specifies the number of constraints in the constraint system.

n_variables: usize

ArithConfig::n_variables specifies the number of variables in the constraint system.

n_public_inputs: usize

ArithConfig::n_public_inputs specifies the number of public inputs in the constraint system.

n_witnesses: usize

ArithConfig::n_witnesses specifies the number of witnesses in the constraint system.

Implementations

Source

impl ArithConfig

pub fn log_constraints(&self) -> usize

ArithConfig::log_constraints returns the base-2 logarithm of the number of constraints in the constraint system.