Module circuits

Module circuits 

This module defines circuits and helpers used by Sonobe.

Modules

utils
This module provides utility circuits.

Structs

Assignments
Assignments represents a full assignment vector z = (u, x, w) for a constraint system.
ConstraintSystemExt
ConstraintSystemExt wraps a ConstraintSystemRef with compile-time flags that control whether constraint matrices (ARITH_ENABLED) and / or assignment vectors (ASSIGNMENTS_ENABLED) are collected during synthesis.

Traits

FCircuit
FCircuit defines the trait of step circuits being proven by IVC schemes.
WitnessToPublic
WitnessToPublic defines a helper trait for marking witness variables as public inputs in the constraint system.

Type Aliases

ArithExtractor
ArithExtractor collects only the constraint matrices (no assignments) from a synthesized circuit.
AssignmentsExtractor
AssignmentsExtractor collects only the assignments (no constraint matrices) from a synthesized circuit.
AssignmentsOwned
AssignmentsOwned is a convenience alias for owned assignment vectors.