Module utils

Module utils 

This module provides utility circuits.

Structs

CircuitForTest
CircuitForTest implements a simple test circuit computing y = x^3 + x + 5 with 4 R1CS constraints.

Functions

constraints_for_test
constraints_for_test returns the R1CS constraints for the test circuit.
satisfying_assignments_for_test
satisfying_assignments_for_test returns a satisfying assignment for the test circuit given an input x.