CircuitForTest

Struct CircuitForTest 

pub struct CircuitForTest<F: PrimeField> {
    pub x: F,
}
CircuitForTest implements a simple test circuit computing y = x^3 + x + 5 with 4 R1CS constraints.

It is used in unit tests to verify constraint extraction and witness generation.

Fields

x: F

CircuitForTest::x is the input variable x of the circuit.