Abstract traits and implementations for commitment schemes.
Modules
- pedersen
- Implementation of the Pedersen commitment scheme, including out-of-circuit widgets and in-circuit gadgets.
Enums
Traits
- Commitment
Def CommitmentDefprovides the core type definitions of a commitment scheme, defining the types of relevant cryptographic objects such as the commitment key, scalars, commitments, and randomness.- Commitment
DefGadget CommitmentDefGadgetspecifies the in-circuit associated types for a commitment scheme gadget.- Commitment
Key CommitmentKeyrepresents a commitment key (e.g., a vector of group generators for many group-based commitment schemes).- Commitment
Ops CommitmentOpsdefines algorithms for commitment schemes.- Commitment
OpsGadget CommitmentOpsGadgetdefines algorithms (majorly the opening algorithm) for commitment schemes in-circuit.- Group
Based Commitment GroupBasedCommitmentis a variant of commitment schemes built on groups (elliptic curves).