pub struct PedersenEmulatedGadget<C: SonobeCurve, const H: bool> { /* private fields */ }Expand description
PedersenEmulatedGadget defines the in-circuit Pedersen gadget that
operates over the scalar field of the curve and supports emulated elliptic
curve point variables as commitments, where H controls whether the scheme
is hiding or not.