pub struct PedersenGadget<C: SonobeCurve, const H: bool> { /* private fields */ }Expand description
PedersenGadget defines the in-circuit Pedersen gadget that operates over
the base field of the curve and supports canonical elliptic curve point
variables as commitments, where H controls whether the scheme is hiding or
not.