PedersenKey

Struct PedersenKey 

pub struct PedersenKey<C: SonobeCurve, const H: bool> { /* private fields */ }
PedersenKey stores the public parameters for the Pedersen commitment scheme, where H controls whether the scheme is hiding or not.