Relation

Trait Relation 

pub trait Relation<W, U> {
    type Error: Error;

    // Required method
    fn check_relation(&self, w: &W, u: &U) -> Result<(), Self::Error>;
}
Relation checks whether a witness W and an instance U satisfy the specified relation.

Required Associated Types

type Error: Error

Relation::Error defines the error type that may occur when checking the relation.

Required Methods

fn check_relation(&self, w: &W, u: &U) -> Result<(), Self::Error>

Relation::check_relation returns Ok(()) when w and u satisfy self, or an error otherwise.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<W, U, A: ArithRelation<W, U>> Relation<W, U> for A