Module traits

Module traits 

This module defines helper traits used across Sonobe’s crates.

Re-exports

pub use crate::algebra::field::SonobeField;
pub use crate::algebra::group::CF1;
pub use crate::algebra::group::CF2;
pub use crate::algebra::group::SonobeCurve;

Traits

Dummy
Dummy provides a way to construct a placeholder (“dummy”) value of a given type, parameterized by some configuration Cfg.
Inputize
Inputize converts a value into a vector of field elements, ordered in the same way as how the value’s corresponding in-circuit variable would be represented in the canonical way in the circuit when allocated as public input.
InputizeEmulated
InputizeEmulated converts a value into a vector of field elements, ordered in the same way as how the value’s corresponding in-circuit variable would be represented in the emulated way in the circuit when allocated as public input.