Inputize

Trait Inputize 

pub trait Inputize<F> {
    // Required method
    fn inputize(&self) -> Vec<F>;
}
Inputize converts a value into a vector of field elements, ordered in the same way as how the value’s corresponding in-circuit variable would be represented in the canonical way in the circuit when allocated as public input.

This is useful for the verifier to compute the public inputs.

Required Methods

fn inputize(&self) -> Vec<F>

Inputize::inputize outputs the underlying field elements of self as if it is allocated in the canonical way in-circuit.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<F, T: Inputize<F>> Inputize<F> for [T]

Source

fn inputize(&self) -> Vec<F>

Source

impl<P: FpConfig<N>, const N: usize> Inputize<Fp<P, N>> for Fp<P, N>

Source

fn inputize(&self) -> Vec<Self>

Source

impl<P: SWCurveConfig<BaseField: SonobeField>> Inputize<<P as CurveConfig>::BaseField> for Projective<P>

Source

fn inputize(&self) -> Vec<P::BaseField>

Implementors