Module transcripts

Module transcripts 

Abstractions of sponges and Fiat-Shamir transcripts.

This module defines the traits that unify hash functions (Poseidon, Griffin, etc.) behind a common absorb / squeeze interface suitable for building non-interactive proofs.

Concrete implementations live in the poseidon and griffin sub-modules.

Re-exports

pub use self::absorbable::Absorbable;
pub use self::absorbable::AbsorbableVar;

Modules

absorbable
This module defines traits for converting values into a form absorbable by a sponge or transcript.
griffin
Implementation of the Griffin circuit-friendly hash function and its parameter generation, as well as out-of-circuit widgets and in-circuit gadgets for permutation, hashing, sponges, and transcripts.
poseidon
Poseidon-based transcript configurations and implementations.
recording
Implementation of transcripts that can automatically record generated challenges, eliminating the need to pass challenges throughout protocols.
replay
Implementation of transcripts that always produces designated challenge values.

Traits

Transcript
Transcript is the out-of-circuit widget for transcripts and sponges.
TranscriptGadget
TranscriptGadget is the in-circuit gadget for transcripts and sponges.