Module absorbable

Module absorbable 

This module defines traits for converting values into a form absorbable by a sponge or transcript.

Implementations are provided for some primitive types as well as composite types (references, tuples, slices, etc.).

Traits

Absorbable
Absorbable is a trait for objects that can be absorbed into a sponge or transcript.
AbsorbableVar
AbsorbableVar is a trait for in-circuit variables that can be absorbed into a sponge or transcript defined over constraint field F.