pub trait Absorbable {
// Required method
fn absorb_into<F: PrimeField>(&self, dest: &mut Vec<F>);
}Expand description
Absorbable is a trait for objects that can be absorbed into a sponge or
transcript.
Required Methods
Sourcefn absorb_into<F: PrimeField>(&self, dest: &mut Vec<F>)
fn absorb_into<F: PrimeField>(&self, dest: &mut Vec<F>)
Absorbable::absorb_into absorbs self into the given destination
vector of field elements.
The implementation should append the field elements representing self
to dest.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".