pub struct Griffin;Expand description
Griffin implements the Griffin permutation and Griffin hash.
Implementations
Sourceimpl Griffin
impl Griffin
Sourcepub fn permute<F: PrimeField>(params: &GriffinParams<F>, input: &mut [F])
pub fn permute<F: PrimeField>(params: &GriffinParams<F>, input: &mut [F])
Griffin::permute applies the Griffin permutation to the given input
state input in place under parameters params.
Sourcepub fn hash<F: PrimeField>(params: &GriffinParams<F>, message: &[F]) -> F
pub fn hash<F: PrimeField>(params: &GriffinParams<F>, message: &[F]) -> F
Griffin::hash implements the Griffin hash function based on the
sponge construction, which produces a single field element as the digest
of the given message message under parameters params.