Module recording

Module recording 

Implementation of transcripts that can automatically record generated challenges, eliminating the need to pass challenges throughout protocols.

Structs

RecordingTranscript
RecordingTranscript wraps a regular transcript to record all challenges it produces.
RecordingTranscriptVar
RecordingTranscriptVar is the in-circuit variable of RecordingTranscript.