Module replay

Module replay 

Implementation of transcripts that always produces designated challenge values.

Structs

ReplayTranscript
ReplayTranscript is a convenience struct that generates specific values as challenges without running the actual hash function.
ReplayTranscriptVar
ReplayTranscriptVar is the in-circuit variable of ReplayTranscript.