ReplayTranscript

Struct ReplayTranscript 

pub struct ReplayTranscript<F> { /* private fields */ }
ReplayTranscript is a convenience struct that generates specific values as challenges without running the actual hash function.

WARNING: This struct itself is insecure. The caller is responsible for checking the validity of the designated challenge values.