pub struct SparseMatrixVar<FV>(pub Vec<Vec<(FV, usize)>>);Expand description
SparseMatrixVar is a sparse matrix represented as a vector of rows,
where each row is a vector of (value, column_index) pairs.
This follows the same format as ark_relations::gr1cs::Matrix.
Tuple Fields
0: Vec<Vec<(FV, usize)>>Trait Implementations
Sourceimpl<F: PrimeField, CF: PrimeField, FV: AllocVar<F, CF>> AllocVar<Vec<Vec<(F, usize)>>, CF> for SparseMatrixVar<FV>
impl<F: PrimeField, CF: PrimeField, FV: AllocVar<F, CF>> AllocVar<Vec<Vec<(F, usize)>>, CF> for SparseMatrixVar<FV>
Sourcefn new_variable<T: Borrow<Matrix<F>>>(
cs: impl Into<Namespace<CF>>,
f: impl FnOnce() -> Result<T, SynthesisError>,
mode: AllocationMode,
) -> Result<Self, SynthesisError>
fn new_variable<T: Borrow<Matrix<F>>>( cs: impl Into<Namespace<CF>>, f: impl FnOnce() -> Result<T, SynthesisError>, mode: AllocationMode, ) -> Result<Self, SynthesisError>
Allocates a new variable of type
Self in the ConstraintSystem cs.
The mode of allocation is decided by mode.Sourcefn new_constant(
cs: impl Into<Namespace<F>>,
t: impl Borrow<V>,
) -> Result<Self, SynthesisError>
fn new_constant( cs: impl Into<Namespace<F>>, t: impl Borrow<V>, ) -> Result<Self, SynthesisError>
Sourcefn new_input<T>(
cs: impl Into<Namespace<F>>,
f: impl FnOnce() -> Result<T, SynthesisError>,
) -> Result<Self, SynthesisError>where
T: Borrow<V>,
fn new_input<T>(
cs: impl Into<Namespace<F>>,
f: impl FnOnce() -> Result<T, SynthesisError>,
) -> Result<Self, SynthesisError>where
T: Borrow<V>,
Allocates a new public input of type
Self in the ConstraintSystem
cs.Sourcefn new_witness<T>(
cs: impl Into<Namespace<F>>,
f: impl FnOnce() -> Result<T, SynthesisError>,
) -> Result<Self, SynthesisError>where
T: Borrow<V>,
fn new_witness<T>(
cs: impl Into<Namespace<F>>,
f: impl FnOnce() -> Result<T, SynthesisError>,
) -> Result<Self, SynthesisError>where
T: Borrow<V>,
Allocates a new private witness of type
Self in the ConstraintSystem
cs.Sourcefn new_variable_with_inferred_mode<T>(
cs: impl Into<Namespace<F>>,
f: impl FnOnce() -> Result<T, SynthesisError>,
) -> Result<Self, SynthesisError>where
T: Borrow<V>,
fn new_variable_with_inferred_mode<T>(
cs: impl Into<Namespace<F>>,
f: impl FnOnce() -> Result<T, SynthesisError>,
) -> Result<Self, SynthesisError>where
T: Borrow<V>,
Allocates a new constant or private witness of type
Self in the
ConstraintSystem cs with the allocation mode inferred from cs.
A constant is allocated if cs is None, and a private witness is
allocated otherwise. Read moreSourceimpl<FV: Clone> Clone for SparseMatrixVar<FV>
impl<FV: Clone> Clone for SparseMatrixVar<FV>
Sourcefn clone(&self) -> SparseMatrixVar<FV>
fn clone(&self) -> SparseMatrixVar<FV>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<FV: Debug> Debug for SparseMatrixVar<FV>
impl<FV: Debug> Debug for SparseMatrixVar<FV>
Sourceimpl<F: PrimeField> MatrixGadget<FpVar<F>> for SparseMatrixVar<FpVar<F>>
impl<F: PrimeField> MatrixGadget<FpVar<F>> for SparseMatrixVar<FpVar<F>>
Sourcefn mul_vector(
&self,
v: &impl Index<usize, Output = FpVar<F>>,
) -> Result<Vec<FpVar<F>>, SynthesisError>
fn mul_vector( &self, v: &impl Index<usize, Output = FpVar<F>>, ) -> Result<Vec<FpVar<F>>, SynthesisError>
Sourceimpl<CF: SonobeField, Cfg> MatrixGadget<LimbedVar<CF, Cfg, false>> for SparseMatrixVar<LimbedVar<CF, Cfg, false>>
impl<CF: SonobeField, Cfg> MatrixGadget<LimbedVar<CF, Cfg, false>> for SparseMatrixVar<LimbedVar<CF, Cfg, false>>
Sourcefn mul_vector(
&self,
v: &impl Index<usize, Output = LimbedVar<CF, Cfg, false>>,
) -> Result<Vec<LimbedVar<CF, Cfg, false>>, SynthesisError>
fn mul_vector( &self, v: &impl Index<usize, Output = LimbedVar<CF, Cfg, false>>, ) -> Result<Vec<LimbedVar<CF, Cfg, false>>, SynthesisError>