This module defines circuits and helpers used by Sonobe.
Modules
- utils
- This module provides utility circuits.
Structs
- Assignments
Assignmentsrepresents a full assignment vectorz = (u, x, w)for a constraint system.- Constraint
System Ext ConstraintSystemExtwraps aConstraintSystemRefwith compile-time flags that control whether constraint matrices (ARITH_ENABLED) and / or assignment vectors (ASSIGNMENTS_ENABLED) are collected during synthesis.
Traits
- FCircuit
FCircuitdefines the trait of step circuits being proven by IVC schemes.- Witness
ToPublic WitnessToPublicdefines a helper trait for marking witness variables as public inputs in the constraint system.
Type Aliases
- Arith
Extractor ArithExtractorcollects only the constraint matrices (no assignments) from a synthesized circuit.- Assignments
Extractor AssignmentsExtractorcollects only the assignments (no constraint matrices) from a synthesized circuit.- Assignments
Owned AssignmentsOwnedis a convenience alias for owned assignment vectors.