Module commitments

Module commitments 

Abstract traits and implementations for commitment schemes.

Modules

pedersen
Implementation of the Pedersen commitment scheme, including out-of-circuit widgets and in-circuit gadgets.

Enums

Error
Error enumerates possible errors during commitment operations.

Traits

CommitmentDef
CommitmentDef provides the core type definitions of a commitment scheme, defining the types of relevant cryptographic objects such as the commitment key, scalars, commitments, and randomness.
CommitmentDefGadget
CommitmentDefGadget specifies the in-circuit associated types for a commitment scheme gadget.
CommitmentKey
CommitmentKey represents a commitment key (e.g., a vector of group generators for many group-based commitment schemes).
CommitmentOps
CommitmentOps defines algorithms for commitment schemes.
CommitmentOpsGadget
CommitmentOpsGadget defines algorithms (majorly the opening algorithm) for commitment schemes in-circuit.
GroupBasedCommitment
GroupBasedCommitment is a variant of commitment schemes built on groups (elliptic curves).