Implementation of the Pedersen commitment scheme, including out-of-circuit widgets and in-circuit gadgets.
The Pedersen commitment to a vector v is computed as <g, v> + h · r,
where g and h are generators, r is a random scalar, and <g, v> is
the multi-scalar multiplication of g and v.
Structs
- Pedersen
Pedersendefines the out-of-circuit Pedersen widget, whereHcontrols whether the scheme is hiding or not.- Pedersen
Emulated Gadget PedersenEmulatedGadgetdefines the in-circuit Pedersen gadget that operates over the scalar field of the curve and supports emulated elliptic curve point variables as commitments, whereHcontrols whether the scheme is hiding or not.- Pedersen
Emulated KeyVar PedersenEmulatedKeyVaris the in-circuit variable forPedersenKey, whose generators are encoded in the emulated form.- Pedersen
Gadget PedersenGadgetdefines the in-circuit Pedersen gadget that operates over the base field of the curve and supports canonical elliptic curve point variables as commitments, whereHcontrols whether the scheme is hiding or not.- Pedersen
Key PedersenKeystores the public parameters for the Pedersen commitment scheme, whereHcontrols whether the scheme is hiding or not.- Pedersen
KeyVar PedersenKeyVaris the in-circuit variable forPedersenKey, whose generators are encoded in the canonical form.