pub trait Inputize<F> {
// Required method
fn inputize(&self) -> Vec<F>;
}Expand description
Inputize converts a value into a vector of field elements, ordered in
the same way as how the value’s corresponding in-circuit variable would be
represented in the canonical way in the circuit when allocated as public
input.
This is useful for the verifier to compute the public inputs.
Required Methods
Sourcefn inputize(&self) -> Vec<F>
fn inputize(&self) -> Vec<F>
Inputize::inputize outputs the underlying field elements of self
as if it is allocated in the canonical way in-circuit.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".