This module defines traits for converting values into a form absorbable by a sponge or transcript.
Implementations are provided for some primitive types as well as composite types (references, tuples, slices, etc.).
Traits
- Absorbable
Absorbableis a trait for objects that can be absorbed into a sponge or transcript.- Absorbable
Var AbsorbableVaris a trait for in-circuit variables that can be absorbed into a sponge or transcript defined over constraint fieldF.